[PATCH] [POWERPC] suppress modpost warnings for references from the .toc

Stephen Rothwell sfr at canb.auug.org.au
Thu May 24 14:16:13 EST 2007


We should do better here by effetively "dereferencing" references to
the .toc (or the .got2) section, but that is much harder.

Signed-off-by: Stephen Rothwell <sfr at canb.auug.org.au>
---
 scripts/mod/modpost.c |    5 ++++-
 1 files changed, 4 insertions(+), 1 deletions(-)

-- 
Cheers,
Stephen Rothwell                    sfr at canb.auug.org.au

diff --git a/scripts/mod/modpost.c b/scripts/mod/modpost.c
index 8e5610d..fe5f89b 100644
--- a/scripts/mod/modpost.c
+++ b/scripts/mod/modpost.c
@@ -865,9 +865,12 @@ static void warn_sec_mismatch(const char *modname, const char *fromsec,
 		return;
 
 	/* fromsec whitelist - without a valid 'before'
 	 * powerpc has a GOT table in .got2 section */
 	if (strcmp(fromsec, ".got2") == 0)
 		return;
+	if (strcmp(fromsec, ".toc") == 0)
+		return;
 
 	if (before && after) {
 		warn("%s(%s+0x%llx): Section mismatch: reference to %s:%s "
@@ -865,9 +865,12 @@ static void warn_sec_mismatch(const char *modname, const char *fromsec,
 
 	/* fromsec whitelist - without a valid 'before'
-	 * powerpc has a GOT table in .got2 section */
+	 * powerpc has a GOT table in .got2 section
+	 * and also a .toc section */
 	if (strcmp(fromsec, ".got2") == 0)
 		return;
-- 
1.5.1.4




More information about the Linuxppc-dev mailing list